@@ -1286,7 +1286,7 @@ imapx_extd_server_authenticate (CamelIMAPXServer *self,
 		}
 
 		sasl = camel_sasl_new ("imap", mechanism, service);
-		if (sasl != NULL) {
+		if (sasl == NULL) {
 			g_set_error (
 				error, CAMEL_SERVICE_ERROR,
 				CAMEL_SERVICE_ERROR_CANT_AUTHENTICATE,
@@ -1775,11 +1775,20 @@ CamelIMAPXExtdServer*
 camel_imapx_extd_server_new (CamelIMAPXExtdStore *store)
 {
 	CamelIMAPXExtdServer *self = NULL;
+	CamelIMAPXServer *is = NULL;
+	CamelService *service = NULL;
+	CamelSession *session = NULL;
 
 	g_assert (CAMEL_IS_IMAPX_EXTD_STORE (store));
 
-	/* FIXME implement me */
-	g_error ("%s: FIXME implement me", __func__);
+	service = CAMEL_SERVICE (store);
+	session = camel_service_get_session (service);
+
+	self = g_object_new (CAMEL_TYPE_IMAPX_EXTD_SERVER, NULL);
+	is = CAMEL_IMAPX_SERVER (self);
+
+	is->session = g_object_ref (session);
+	is->store = store;
 
 	return self;
 }
