@@ -25,8 +25,13 @@
 
 /*----------------------------------------------------------------------------*/
 
+#include <config.h>
+
 #include <string.h>
 #include <time.h>
+
+#include <glib/gi18n-lib.h>
+
 #include <libical/ical.h>
 #include <libedataserver/e-source.h>
 
@@ -37,19 +42,24 @@
 
 #include "kolab-util-backend.h"
 
-const gchar *kolab_sync_strategy_desc[KOLAB_SYNC_LAST_STRATEGY] = {
-	KOLAB_STRATEGY_DESC_NEWEST,
-	KOLAB_STRATEGY_DESC_SERVER,
-	KOLAB_STRATEGY_DESC_CLIENT,
-	KOLAB_STRATEGY_DESC_DUPE
+/*----------------------------------------------------------------------------*/
+
+static const gchar *kolab_sync_strategy_desc[KOLAB_SYNC_LAST_STRATEGY] = {
+	N_(KOLAB_STRATEGY_DESC_NEWEST),
+	N_(KOLAB_STRATEGY_DESC_SERVER),
+	N_(KOLAB_STRATEGY_DESC_CLIENT),
+	N_(KOLAB_STRATEGY_DESC_DUPE)
 };
 
-const gchar *kolab_tls_variant_desc[KOLAB_TLS_LAST_VARIANT] = {
-	KOLAB_TLS_DESC_VARIANT_NONE,
-	KOLAB_TLS_DESC_VARIANT_SSL,
-	KOLAB_TLS_DESC_VARIANT_TLS
+static const gchar *kolab_tls_variant_desc[KOLAB_TLS_LAST_VARIANT] = {
+	N_(KOLAB_TLS_DESC_VARIANT_NONE),
+	N_(KOLAB_TLS_DESC_VARIANT_SSL),
+	N_(KOLAB_TLS_DESC_VARIANT_TLS)
 };
 
+/*----------------------------------------------------------------------------*/
+/* local statics */
+
 /*----------------------------------------------------------------------------*/
 /* GError for libekolabbackend */
 
@@ -174,7 +184,7 @@ KolabSyncStrategyID
 kolab_util_misc_sync_value_from_property (const gchar *sync_prop)
 {
 	KolabSyncStrategyID sid = KOLAB_SYNC_STRATEGY_DEFAULT;
-	g_assert (sync_prop != NULL);
+	g_return_val_if_fail (sync_prop != NULL, KOLAB_SYNC_STRATEGY_DEFAULT);
 	sid = kolab_util_misc_generic_integer_from_property (sync_prop,
 	                                                     KOLAB_SYNC_STRATEGY_DEFAULT);
 	return sid;
@@ -184,7 +194,7 @@ KolabTLSVariantID
 kolab_util_misc_tls_variant_from_property (const gchar *tls_variant)
 {
 	KolabTLSVariantID tvid = KOLAB_TLS_VARIANT_DEFAULT;
-	g_assert (tls_variant != NULL);
+	g_return_val_if_fail (tls_variant != NULL, KOLAB_TLS_VARIANT_DEFAULT);
 	tvid = kolab_util_misc_generic_integer_from_property (tls_variant,
 	                                                      KOLAB_TLS_VARIANT_DEFAULT);
 	return tvid;
@@ -194,7 +204,7 @@ KolabReqPkcs11
 kolab_util_misc_req_pkcs11_from_property (const gchar *req_pkcs11_prop)
 {
 	KolabReqPkcs11 pkreq = KOLAB_PKCS11_INFRASTRUCTURE_DEFAULT;
-	g_assert (req_pkcs11_prop != NULL);
+	g_return_val_if_fail (req_pkcs11_prop != NULL, KOLAB_PKCS11_INFRASTRUCTURE_DEFAULT);
 	pkreq = kolab_util_misc_generic_integer_from_property (req_pkcs11_prop,
 	                                                       KOLAB_PKCS11_INFRASTRUCTURE_DEFAULT);
 	return pkreq;
@@ -410,3 +420,22 @@ kolab_util_backend_sqlite_db_new_open (KolabUtilSqliteDb **kdb,
 
 	return TRUE;
 }
+
+/*----------------------------------------------------------------------------*/
+/* mapping of description IDs to description strings */
+
+const gchar*
+kolab_util_backend_get_sync_strategy_desc (KolabSyncStrategyID id)
+{
+	g_assert (id < KOLAB_SYNC_LAST_STRATEGY);
+
+	return gettext (kolab_sync_strategy_desc[id]);
+}
+
+const gchar*
+kolab_util_backend_get_tls_variant_desc (KolabTLSVariantID id)
+{
+	g_assert (id < KOLAB_TLS_LAST_VARIANT);
+
+	return gettext (kolab_tls_variant_desc[id]);
+}
