@@ -94,10 +94,41 @@ typedef enum {
 
 /*----------------------------------------------------------------------------*/
 
-/*TODO get rid of these globals if possible */
+/* TODO get rid of these globals if possible */
 /* static SoupSession *kolab_soup_session = NULL; */
 static CURL *kolab_curl_handle = NULL;
 
+/*----------------------------------------------------------------------------*/
+/* KolabUtilHttpJob */
+
+KolabUtilHttpJob*
+kolab_util_http_job_new (void)
+{
+	KolabUtilHttpJob *job = g_new0 (KolabUtilHttpJob, 1);
+	job->url = NULL;
+	job->buffer = NULL;
+	job->nbytes = 0;
+	job->pkcs11pin = NULL;
+
+	return job;
+}
+
+void
+kolab_util_http_job_free (KolabUtilHttpJob *job)
+{
+	if (job == NULL)
+		return;
+
+	if (job->url != NULL)
+		camel_url_free (job->url);
+	if (job->buffer != NULL) {
+		g_byte_array_free (job->buffer, TRUE);
+	}
+	if (job->pkcs11pin != NULL)
+		g_free (job->pkcs11pin);
+	g_free (job);
+}
+
 /*----------------------------------------------------------------------------*/
 /* LibSoup */
 #if 0
@@ -108,7 +139,7 @@ kolab_util_http_soup_authenticate (SoupSession *session,
                                    gboolean retrying,
                                    gpointer data)
 {
-	KolabHttpJob *job;
+	KolabUtilHttpJob *job;
 
 	(void)session;
 	(void)msg;
@@ -117,7 +148,7 @@ kolab_util_http_soup_authenticate (SoupSession *session,
 	if (retrying)
 		return;
 
-	job = (KolabHttpJob*) data;
+	job = (KolabUtilHttpJob*) data;
 	g_assert( job != NULL);
 	soup_auth_authenticate (auth,
 	                        job->url->user,
@@ -125,7 +156,7 @@ kolab_util_http_soup_authenticate (SoupSession *session,
 }
 
 static gssize
-kolab_util_http_soup_get (const KolabHttpJob *job, GError **error)
+kolab_util_http_soup_get (const KolabUtilHttpJob *job, GError **error)
 {
 	g_error ("%s: not implemented.", __func__);
 	SoupMessage *msg = NULL;
@@ -141,7 +172,7 @@ kolab_util_http_soup_get (const KolabHttpJob *job, GError **error)
 	/* connect the "authenticate" signal handler,
 	 * disconnect a previously connected one.
 	 * TODO: check whether we need to disconnect-connect
-	 *       a handler here (KolabHttpJob* may point to
+	 *       a handler here (KolabUtilHttpJob* may point to
 	 *       an address different from the one we were
 	 *       called upon last time)
 	 */
@@ -262,7 +293,7 @@ kolab_util_http_curl_set_genopts (void)
 }
 
 static CURLcode
-kolab_util_http_curl_set_jobopts (const KolabHttpJob *job)
+kolab_util_http_curl_set_jobopts (const KolabUtilHttpJob *job)
 {
 	CURLcode curlcode;
 	gchar *usrpwd = NULL;
@@ -289,7 +320,7 @@ kolab_util_http_curl_set_jobopts (const KolabHttpJob *job)
 
 	/* set username/password for basic auth */
 	if (job->url->user != NULL) {
-		/* FIXME get password from CamelSettings (change KolabHttpJob) */
+		/* FIXME get password from CamelSettings (change KolabUtilHttpJob) */
 		g_warning ("%s: FIXME get password from CamelSettings", __func__);
 #if 0
 		if (job->url->passwd != NULL)
@@ -330,7 +361,7 @@ kolab_util_http_curl_set_jobopts (const KolabHttpJob *job)
 }
 
 static gssize
-kolab_util_http_curl_get (KolabHttpJob *job, GError **error)
+kolab_util_http_curl_get (KolabUtilHttpJob *job, GError **error)
 {
 	gssize nbytes = -1;
 	CURLcode curlcode;
@@ -456,14 +487,14 @@ kolab_util_http_shutdown (void)
  * kolab_util_http_get:
  * @job: the job description structure for issuing the HTTP request
  *
- * Issue a HTTP-GET request. The protocol part of the #KolabHttpJob.url
+ * Issue a HTTP-GET request. The protocol part of the #KolabUtilHttpJob.url
  * specifies whether or not SSL will be used for transport security.
  *
  * Returns: the number of bytes read from the server. If an error occured,
  * before data was read, -1 is returned.
  */
 gssize
-kolab_util_http_get (KolabHttpJob *job, GError **error)
+kolab_util_http_get (KolabUtilHttpJob *job, GError **error)
 {
 	gssize nbytes = -1;
 
